14.91. cdist-type__package_pkg_freebsd(7) — cdist 4.8.1 documentation

# 14.91. cdist-type__package_pkg_freebsd(7)

## 14.91.1. NAME

cdist-type__package_pkg_freebsd - Manage FreeBSD packages

## 14.91.2. DESCRIPTION

This type is usually used on FreeBSD to manage packages.

## 14.91.3. REQUIRED PARAMETERS

None

## 14.91.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
flavor
  If supplied, use to avoid ambiguity.
version
  If supplied, use to install a specific version of the package named.
pkgsite
  If supplied, use to install from a specific package repository.
state
  Either "present" or "absent", defaults to "present"

## 14.91.5. EXAMPLES

    # Ensure zsh is installed
    __package_pkg_freebsd zsh --state present

    # Ensure vim is installed, use flavor no_x11
    __package_pkg_freebsd vim --state present --flavor no_x11

    # If you don't want to follow pythonX packages, but always use python
    __package_pkg_freebsd python --state present --name python2

    # Remove obsolete package
    __package_pkg_freebsd puppet --state absent

## 14.91.6. SEE ALSO

cdist-type__package(7)

## 14.91.7. AUTHORS

Jake Guffey <jake.guffey--@--eprotex.com>

## 14.91.8. COPYING

Copyright (C) 2012 Jake Guffey. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.